addTiming method
Adds a specific timing named name in the currently presented View. The
timing duration will be computed as the number of nanoseconds between the
time the View was started and the time the timing was added.
Implementation
void addTiming(String name) {
final currentTime = timeProvider.now();
wrap('rum.addTiming', logger, null, () {
return _platform.addTiming(currentTime, name);
});
}