addViewLoadingTime method

void addViewLoadingTime({
  1. bool override = false,
})

Adds view loading time to current RUM view based on the time elapsed since the view was started. If this method is called multiple times, only the first timing is used, unless overwrite is set to true. If overwrite is true, the new load timing overwrites any previous value.

Note: This API is experimental and may change in the future.

Implementation

void addViewLoadingTime({bool override = false}) {
  wrap('rum.addViewLoadingTime', logger, null, () {
    return _platform.addViewLoadingTime(override);
  });
}