stopResource method
void
stopResource(])
Notifies that the Resource identified by key stopped being loaded
successfully and supplies additional information about the Resource loaded,
including its kind, the statusCode of the response, the size of the
Resource, and any other custom attributes to attach to the resource.
Implementation
void stopResource(
String key,
int? statusCode,
RumResourceType kind, [
int? size,
Map<String, Object?> attributes = const {},
]) {
wrap('rum.stopResource', logger, attributes, () {
final currentTime = timeProvider.now();
return _platform.stopResource(
currentTime,
key,
statusCode,
kind,
size,
attributes,
);
});
}