addViewAttributes method
Adds a collection of custom attributes to the current view. Note that
values in this map must be supported by StandardMessageCodec.
Implementation
void addViewAttributes(Map<String, Object?> attributes) {
wrap('rum.addViewAttribute', logger, {'attributes': attributes}, () {
return _platform.addViewAttributes(attributes);
});
}